@@ -11,15 +11,7 @@ our $VERSION;
 # $VERSION declaration must stay up here, ahead of any other package
 # declarations, as to not confuse various modules attempting to determine
 # this ones version, whether that be s.c.o. or Module::Metadata, etc
-$VERSION = '0.082843_01';
-
-{
-  package
-    DBIx::Class::_ENV_;
-
-  require constant;
-  constant->import( DEVREL => ( ($DBIx::Class::VERSION =~ /_/) ? 1 : 0 ) );
-}
+$VERSION = '0.082899_01';
 
 $VERSION = eval $VERSION if $VERSION =~ /_/; # numify for warning-free dev releases
 
@@ -35,13 +27,6 @@ use DBIx::Class::Exception;
 __PACKAGE__->mk_group_accessors(inherited => '_skip_namespace_frames');
 __PACKAGE__->_skip_namespace_frames('^DBIx::Class|^SQL::Abstract|^Try::Tiny|^Class::Accessor::Grouped|^Context::Preserve');
 
-# FIXME - this is not really necessary, and is in
-# fact going to slow things down a bit
-# However it is the right thing to do in order to get
-# various install bases to highlight their brokenness
-# Remove at some unknown point in the future
-sub DESTROY { &DBIx::Class::_Util::detected_reinvoked_destructor }
-
 sub mk_classdata {
   shift->mk_classaccessor(@_);
 }
@@ -82,20 +67,6 @@ sub DBIx::Class::_ENV_::HELP_URL () {
 
 __END__
 
-# This is the only file where an explicit =encoding is needed,
-# as the distbuild-time injected author list is utf8 encoded
-# Without this pod2text output is less than ideal
-#
-# A bit regarding selection/compatiblity:
-# Before 5.8.7 UTF-8 was == utf8, both behaving like the (lax) utf8 we know today
-# Then https://www.nntp.perl.org/group/perl.unicode/2004/12/msg2705.html happened
-# Encode way way before 5.8.0 supported UTF-8: https://metacpan.org/source/DANKOGAI/Encode-1.00/lib/Encode/Supported.pod#L44
-# so it is safe for the oldest toolchains.
-# Additionally we inject all the utf8 programattically and test its well-formedness
-# so all is well
-#
-=encoding UTF-8
-
 =head1 NAME
 
 DBIx::Class - Extensible and flexible object <-> relational mapper.
@@ -119,11 +90,18 @@ list is sorted by "fastest response time"):
 
 =over
 
-=item * RT Bug Tracker: L<https://rt.cpan.org/Public/Dist/Display.html?Name=DBIx-Class>
+=item * IRC: irc.perl.org#dbix-class
 
-=item * Email: L<mailto:bug-DBIx-Class@rt.cpan.org>
+=for html
+<a href="https://chat.mibbit.com/#dbix-class@irc.perl.org">(click for instant chatroom login)</a>
 
-=item * Twitter: L<https://twitter.com/intent/tweet?text=%40ribasushi%20%23DBIC>
+=item * Mailing list: L<http://lists.scsys.co.uk/mailman/listinfo/dbix-class>
+
+=item * RT Bug Tracker: L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-Class>
+
+=item * Twitter: L<https://www.twitter.com/dbix_class>
+
+=item * Web Site: L<http://www.dbix-class.org/>
 
 =back
 
@@ -198,7 +176,7 @@ Then you can use these classes in your application's code:
   # Create a result set to search for artists.
   # This does not query the DB.
   my $johns_rs = $schema->resultset('Artist')->search(
-    # Build your WHERE using an SQL::Abstract::Classic-compatible structure:
+    # Build your WHERE using an SQL::Abstract structure:
     { name => { like => 'John%' } }
   );
 
@@ -224,7 +202,7 @@ Then you can use these classes in your application's code:
   my $cd = $millennium_cds_rs->next; # SELECT ... FROM cds JOIN artists ...
   my $cd_artist_name = $cd->artist->name; # Already has the data so no 2nd query
 
-  # new() makes a Result object but doesn't insert it into the DB.
+  # new() makes a Result object but doesnt insert it into the DB.
   # create() is the same as new() then insert().
   my $new_cd = $schema->resultset('CD')->new({ title => 'Spoon' });
   $new_cd->artist($cd->artist);
@@ -276,9 +254,11 @@ merged back to trunk for a major release.
 Contributions are always welcome, in all usable forms (we especially
 welcome documentation improvements). The delivery methods include git-
 or unified-diff formatted patches, GitHub pull requests, or plain bug
-reports either via RT or the Mailing list. Do not hesitate to
-L<get in touch|/GETTING HELP/SUPPORT> with any further questions you may
-have.
+reports either via RT or the Mailing list. Contributors are generally
+granted access to the official repository after their first several
+patches pass successful review. Don't hesitate to
+L<contact|/GETTING HELP/SUPPORT> either of the L</CAT HERDERS> with
+any further questions you may have.
 
 =for comment
 FIXME: Getty, frew and jnap need to get off their asses and finish the contrib section so we can link it here ;)
@@ -288,9 +268,18 @@ accessible at the following locations:
 
 =over
 
-=item * Current git repository: L<https://github.com/Perl5/DBIx-Class>
+=item * Official repo: L<git://git.shadowcat.co.uk/dbsrgits/DBIx-Class.git>
 
-=item * Travis-CI log: L<https://travis-ci.com/github/Perl5/DBIx-Class/branches>
+=item * Official gitweb: L<http://git.shadowcat.co.uk/gitweb/gitweb.cgi?p=dbsrgits/DBIx-Class.git>
+
+=item * GitHub mirror: L<https://github.com/dbsrgits/DBIx-Class>
+
+=item * Authorized committers: L<ssh://dbsrgits@git.shadowcat.co.uk/DBIx-Class.git>
+
+=item * Travis-CI log: L<https://travis-ci.org/dbsrgits/dbix-class/builds>
+
+=for html
+&#x21AA; Stable branch CI status: <img src="https://secure.travis-ci.org/dbsrgits/dbix-class.png?branch=master"></img>
 
 =back
 
@@ -311,6 +300,23 @@ the root of this distribution (or repository). The canonical source of
 per-line authorship is the L<git repository|/HOW TO CONTRIBUTE> history
 itself.
 
+=head1 CAT HERDERS
+
+The fine folks nudging the project in a particular direction:
+
+=over
+
+B<ribasushi>: Peter Rabbitson <ribasushi@cpan.org>
+(present day maintenance and controlled evolution)
+
+B<castaway>: Jess Robinson <castaway@desert-island.me.uk>
+(lions share of the reference documentation and manuals)
+
+B<mst>: Matt S Trout <mst@shadowcat.co.uk> (project founder -
+original idea, architecture and implementation)
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2005 by mst, castaway, ribasushi, and other DBIx::Class
